@@ -18,7 +18,6 @@ class Services(metaclass=SingletonMeta):
     _config: Optional[dict] = None
     _initialized: bool = False
     _registered_senders: List[str] = []
-    _mq_tasks: List[asyncio.Task] = []
     _instance: Optional['Services'] = None
     _app: Optional[FastAPI] = None
     _user_lifespan: Optional[Callable] = None
@@ -71,8 +70,8 @@ class Services(metaclass=SingletonMeta):
         app.state.config = {
             "host": cls._config.get('Host', '0.0.0.0'),
             "port": cls._config.get('Port', 8080),
-            "workers": cls._config.get('Workers', 1),
-            "h11_max_incomplete_event_size": cls._config.get('H11MaxIncompleteEventSize', 1024 * 1024 * 100)
+            "workers": cls._config.get('Workers', 2),
+            "h11_max_incomplete_event_size": cls._config.get('H11MaxIncompleteEventSize', 1024 * 1024 * 10)
         }
 
         # 立即配置非异步服务（在应用启动前）
@@ -145,17 +144,17 @@ class Services(metaclass=SingletonMeta):
         has_listeners: bool = False,
         has_senders: bool = False,
     ):
-        """异步设置MQ相关服务（适配新的RabbitMQService）"""
+        """异步设置MQ相关服务（适配单通道RabbitMQService）"""
         # 初始化RabbitMQ服务，传递状态
         RabbitMQService.init(self._config, has_listeners, has_senders)
 
-        # 等待RabbitMQ连接池初始化完成（最多等待30秒）
+        # 优化：等待连接池“存在且初始化完成”（避免提前执行后续逻辑）
         start_time = asyncio.get_event_loop().time()
-        while not RabbitMQService._connection_pool and not RabbitMQService._is_shutdown:
+        while not (RabbitMQService._connection_pool and RabbitMQService._connection_pool._initialized) and not RabbitMQService._is_shutdown:
             if asyncio.get_event_loop().time() - start_time > 30:
-                raise TimeoutError("RabbitMQ连接池初始化超时")
+                raise TimeoutError("RabbitMQ连接池初始化超时（30秒）")
             logging.info("等待RabbitMQ连接池初始化...")
-            await asyncio.sleep(1)
+            await asyncio.sleep(0.5)
 
         # 设置发送器，传递是否有监听器的标志
         if rabbitmq_senders:
@@ -174,10 +173,11 @@ class Services(metaclass=SingletonMeta):
         # 验证初始化结果
         if has_listeners:
             # 异步获取客户端数量（适配新的RabbitMQService）
-            listener_count = len(RabbitMQService._clients)
+            listener_count = len(
+                RabbitMQService._consumer_tasks)
             logging.info(f"监听器初始化完成，共启动 {listener_count} 个消费者")
             if listener_count == 0:
-                logging.warning("未成功初始化任何监听器，请检查配置")
+                logging.warning("未成功初始化任何监听器，请检查配置或MQ服务状态")
 
     async def _setup_senders_async(self, rabbitmq_senders, has_listeners: bool):
         """设置发送器（适配新的RabbitMQService异步方法）"""
@@ -202,7 +202,7 @@ class Services(metaclass=SingletonMeta):
         max_retries: int = 3,
         retry_delay: float = 1.0, **kwargs
     ) -> None:
-        """发送消息，添加重试机制（适配新的RabbitMQService异步API）"""
+        """发送消息，添加重试机制（适配单通道RabbitMQService）"""
         if not cls._initialized or not cls._loop:
             logging.error("Services not properly initialized!")
             raise ValueError("服务未正确初始化")
@@ -243,26 +243,16 @@ class Services(metaclass=SingletonMeta):
 
     @classmethod
     async def shutdown(cls):
-        """关闭所有服务（线程安全，适配新的RabbitMQService关闭逻辑）"""
+        """关闭所有服务（适配单通道RabbitMQService关闭逻辑）"""
         async with cls._shutdown_lock:
             if RabbitMQService._is_shutdown:
                 logging.info("RabbitMQService已关闭，无需重复操作")
                 return
 
-            # 取消所有MQ任务
-            for task in Services._mq_tasks:
-                if not task.done():
-                    task.cancel()
-                    try:
-                        await task
-                    except asyncio.CancelledError:
-                        logging.info(f"MQ任务 {task.get_name()} 已取消")
-
-            # 关闭RabbitMQ服务（异步调用）
+            # 关闭RabbitMQ服务（异步调用，内部会关闭所有客户端+消费任务）
             await RabbitMQService.shutdown()
 
             # 清理全局状态
             cls._initialized = False
             cls._registered_senders.clear()
-            cls._mq_tasks.clear()
             logging.info("所有服务已关闭")
